
import { base, getToken } from './_config'

export function getUrlImagen(id_paradero) {
    return `${base}/paraderos/image/${id_paradero}`
}

export async function getParaderos(params) {
    const query = !params ? '' : '?' + (new URLSearchParams(params).toString());
    const res = await fetch(`${base}/paraderos/${query}`, {
        headers: { "Authorization": `Bearer ${getToken()}`, "Content-Type": "application/json" }
    })
    if (!res.ok) throw await res.text()
    return res.json()
}

export async function getParadero(rut) {
    const res = await fetch(`${base}/paraderos/${rut}/`, {
        headers: { "Authorization": `Bearer ${getToken()}`, "Content-Type": "application/json" }
    })
    if (!res.ok) throw await res.text()
    return res.json()
}

export async function createParadero(data) {
    const res = await fetch(`${base}/paraderos/`, {
        method: 'POST',
        body: JSON.stringify(data),
        headers: { "Authorization": `Bearer ${getToken()}`, "Content-Type": "application/json" }
    })
    if (!res.ok) throw await res.text()
    return res.json()
}

export async function updateParadero({ id_paradero: id = null,  ...data }) {
    const res = await fetch(`${base}/paraderos/${id}/`, {
        method: 'PATCH',
        body: JSON.stringify(data),
        headers: { "Authorization": `Bearer ${getToken()}`, "Content-Type": "application/json" }
    })
    if (!res.ok) throw await res.text()
    return res.json()
}

export async function deleteParadero(id) {
    const res = await fetch(`${base}/paraderos/${id}/`, {
        method: 'DELETE',
        headers: { "Authorization": `Bearer ${getToken()}`, "Content-Type": "application/json" }
    })
    if (!res.ok) throw await res.text()
    return res.json()
}

export async function saveImageParadero(id = null,  file) {
    const form = new FormData()
    form.append('imagen', file)

    const res = await fetch(`${base}/paraderos/image/${id}/`, {
        method: 'POST',
        body: form,
        headers: { "Authorization": `Bearer ${getToken()}` }
    })
    if (!res.ok) throw await res.text()
    return res.json()
}